.. :changelog:

History
-------

0.1.1 (2015-01-19)
------------------

* Removed an excess creation of a CeleryDataManager that was a left-over from
  a previous approach. While this didn't create a bug, it wasted memory.


0.1.0 (2015-01-19)
------------------

* Initial functionality, but more testing of edge cases is needed to ensure
  that it works correctly in all cases, and with other versions of Celery.
* First release on PyPI.

